@@ -145,12 +145,11 @@
 #define XML_CHECKPRIVATEADDRESSSPACE	"checkprivateaddressspace"
 #define XML_PRIVATEADDRESSSPACEONLY	"privateaddressspaceonly"
 
-#define XML_DCLIB_DATAPATH		"dclibdatapath"
 #define XML_DCLIB_PLUGINPATH		"dclibpluginpath"
 #define XML_DYNAMICUPLOADRATE		"dynamicuploadrate"
 
-#define XML_CHATSENDOFFLINEMESSAGES	"chatsendofflinemessages"
-#define XML_CHATRECVOFFLINEMESSAGES	"chatrecvofflinemessages"
+#define XML_CHATSENDTOOFFLINE		"chatsendtooffline"
+#define XML_CHATRECVFROMOFFLINE		"chatrecvfromoffline"
 
 #define XML_DC				"dc"
 #define XML_VERSION			"version"
@@ -221,7 +220,7 @@
 #include "cdownloadqueue.h"
 #include "clistenmanager.h"
 
-#include <cstdio>
+#include <stdio.h>
 
 /**
  * default hub url list - see dcpp/SettingsManager.cpp in the DC++ sources for more
@@ -285,7 +284,6 @@ CConfig::CConfig( CString configpath )
 	d.CreatePath(DCGUI_FILELIST_PATH);
 	
 	// default settings
-	sEMail      = "email";
 	sNick       = "nick";
 	sSearchNick = "nick_search";
 	sSpeed      = "28.8Kbps";
@@ -317,8 +315,8 @@ CConfig::CConfig( CString configpath )
 	bCheckPrivateAddressSpace       = false;
 	bPrivateAddressSpaceOnly	= false;
 	bDynamicUploadRate              = false;
-	bChatSendOfflineMessages 	= false;
-	bChatRecvOfflineMessages 	= true;
+	bChatSendToOffline		= false;
+	bChatRecvFromOffline		= true;
 	bTransferAutoSearch             = false;
 
 	iTransferResendTimeout   = 100;
@@ -345,50 +343,9 @@ CConfig::CConfig( CString configpath )
 	m_nPublicHubID = 0;
 	m_nBookHubID   = 0;
 
-#ifndef WIN32
-	m_sDCLibDataPath  = DCLIB_DATAPATH;
-	m_sDCLibDataPath += "/dclib";
+	/* plugins disabled by default - leave string empty */
 	/* m_sDCLibPluginPath = DCLIB_PLUGINDIR; */
-#else
-	// read datapath from registrie
-	LONG Status;
-	HKEY regdcgui;
-	UCHAR buffer[1024];
-	DWORD dim = 1024;
 
-	m_sDCLibDataPath.Empty();
-
-	// load from HKLM
-	Status = RegOpenKeyEx(HKEY_LOCAL_MACHINE,
-		TEXT("Software\\VALKNUT"),
-		0,
-		KEY_READ,
-		&regdcgui);
-
-	if ( Status != ERROR_SUCCESS )
-	{
-		// load from HKCU
-		Status = RegOpenKeyEx(HKEY_CURRENT_USER,
-			TEXT("Software\\VALKNUT"),
-			0,
-			KEY_READ,
-			&regdcgui);
-	}
-	
-	if ( Status == ERROR_SUCCESS )
-	{
-		Status = RegQueryValueEx(regdcgui,"Path",NULL,NULL,buffer,&dim);
-
-		if ( Status == ERROR_SUCCESS )
-		{
-			m_sDCLibDataPath = (char*)buffer;
-		}
-
-		RegCloseKey(regdcgui);
-	}
-	
-	/* m_sDCLibPluginPath = m_sDCLibDataPath; */
-#endif
 	m_nReloadHubListTime = 0;
 	m_nRecreateShareListTime = 0;
 	m_bCreateFile = false;
@@ -533,12 +490,12 @@ int CConfig::LoadDCLib()
 	{
 		/* adc:// or adcs:// hubs will not be shown */
 		DCConfigHubListUrl * hublisturl = new DCConfigHubListUrl();
-		hublisturl->sUrl = "http://hublist.hubtracker.com/hublist.xml.bz2";
+		hublisturl->sUrl = "http://hublist.openhublist.org/hublist.xml.bz2";
 		hublisturl->bEnabled = true;
 		pHubListUrlList.Add(hublisturl);
 		
 		hublisturl = new DCConfigHubListUrl();
-		hublisturl->sUrl = "http://hublist.hubtracker.com/hublist.config.bz2";
+		hublisturl->sUrl = "http://hublist.openhublist.org/hublist.config.bz2";
 		hublisturl->bEnabled = false;
 		pHubListUrlList.Add(hublisturl);
 		
@@ -673,10 +630,9 @@ int CConfig::SaveDCLib()
 	xml->NewNumericChild( XML_RECONNECTTIMEOUT, iReconnectTimeout );
 	xml->NewNumericChild( XML_TRANSFERRESPONSETIMEOUT, iTransferResponseTimeout );
 	xml->NewNumericChild( XML_TRANSFERRESENDTIMEOUT, iTransferResendTimeout );
-	xml->NewStringChild( XML_DCLIB_DATAPATH, m_sDCLibDataPath );
 	xml->NewStringChild( XML_DCLIB_PLUGINPATH, m_sDCLibPluginPath );
-	xml->NewBoolChild( XML_CHATSENDOFFLINEMESSAGES, bChatSendOfflineMessages );
-	xml->NewBoolChild( XML_CHATRECVOFFLINEMESSAGES, bChatRecvOfflineMessages );
+	xml->NewBoolChild( XML_CHATSENDTOOFFLINE, bChatSendToOffline );
+	xml->NewBoolChild( XML_CHATRECVFROMOFFLINE, bChatRecvFromOffline );
 	xml->NewBoolChild( XML_HUBLISTSTORELOCAL, bHubListStoreLocal );
 	xml->NewNumericChild( XML_RELOAD_HUBLIST_TIME, m_nReloadHubListTime );
 	xml->NewBoolChild( XML_FORCEMOVEENABLED, bForceMoveEnabled );
@@ -1589,14 +1545,12 @@ void CConfig::ParseDCLibConfig( CXml * xml )
 					iTransferResendTimeout = xml->Content().asINT();
 				else if ( xml_name2 == XML_FORCEMOVEENABLED )
 					bForceMoveEnabled = xml->GetBoolChild();
-				else if ( xml_name2 == XML_DCLIB_DATAPATH )
-					m_sDCLibDataPath = xml->Content();
 				else if ( xml_name2 == XML_DCLIB_PLUGINPATH )
 					m_sDCLibPluginPath = xml->Content();
-				else if ( xml_name2 == XML_CHATSENDOFFLINEMESSAGES )
-					bChatSendOfflineMessages = xml->GetBoolChild();
-				else if ( xml_name2 == XML_CHATRECVOFFLINEMESSAGES )
-					bChatRecvOfflineMessages = xml->GetBoolChild();
+				else if ( xml_name2 == XML_CHATSENDTOOFFLINE )
+					bChatSendToOffline = xml->GetBoolChild();
+				else if ( xml_name2 == XML_CHATRECVFROMOFFLINE )
+					bChatRecvFromOffline = xml->GetBoolChild();
 				else if ( xml_name2 == XML_RELOAD_HUBLIST_TIME )
 					m_nReloadHubListTime = xml->Content().asINT();
 				else if ( xml_name2 == XML_DISABLEHASHLIST )
@@ -3274,3 +3228,12 @@ void CConfig::SetHost( CString newhost )
 		m_Mutex.UnLock();
 	}
 }
+
+/** */
+void CConfig::SetAwayMode( eUserAwayMode mode )
+{
+	m_Mutex.Lock();
+	eAwayMode = mode;
+	m_Mutex.UnLock();
+}
+
